Post

๐˜›๐˜ฉ๐˜ช๐˜ด ๐˜ณ๐˜ฆ๐˜ด๐˜ถ๐˜ญ๐˜ต๐˜ด ๐˜ช๐˜ฏ ๐˜ญ๐˜ข๐˜ป๐˜บ-๐˜ญ๐˜ฐ๐˜ข๐˜ฅ๐˜ช๐˜ฏ๐˜จ ๐˜ค๐˜ถ๐˜ด๐˜ต๐˜ฐ๐˜ฎ ๐˜ฆ๐˜ญ๐˜ฆ๐˜ฎ๐˜ฆ๐˜ฏ๐˜ต๐˜ด ๐˜ฑ๐˜ณ๐˜ฆ๐˜ด๐˜ฆ๐˜ฏ๐˜ต ๐˜ช๐˜ฏ ๐˜ต๐˜ฉ๐˜ฆ ๐˜‹๐˜–๐˜” ๐˜ข๐˜ต ๐˜ญ๐˜ฐ๐˜ข๐˜ฅ ๐˜ต๐˜ช๐˜ฎ๐˜ฆ, ๐˜ฆ๐˜ฏ๐˜ต๐˜ช๐˜ณ๐˜ฆ๐˜ญ๐˜บ ๐˜ข๐˜ด๐˜บ๐˜ฏ๐˜ค ๐˜ข๐˜ฏ๐˜ฅ ๐˜ช๐˜ฏ ๐˜ฑ๐˜ข๐˜ณ๐˜ข๐˜ญ๐˜ญ๐˜ฆ๐˜ญ Yes lazy, and LATE because it can only run AFTER all DOM is parsed ๐˜ž๐˜ฆ ๐˜ข๐˜ญ๐˜ด๐˜ฐ ๐˜ข๐˜ถ๐˜ต๐˜ฐ๐˜ฎ๐˜ข๐˜ต๐˜ช๐˜ค๐˜ข๐˜ญ๐˜ญ๐˜บ ๐˜ญ๐˜ฐ๐˜ข๐˜ฅ ๐˜ฆ๐˜ท๐˜ฆ๐˜ณ๐˜บ ๐˜ธ๐˜ฆ๐˜ฃ ๐˜ค๐˜ฐ๐˜ฎ๐˜ฑ๐˜ฐ๐˜ฏ๐˜ฆ๐˜ฏ๐˜ต ๐˜ช๐˜ฏ ๐˜ฐ๐˜ถ๐˜ณ ๐˜š๐˜š๐˜™ ๐˜ฃ๐˜ถ๐˜ฏ๐˜ฅ๐˜ญ๐˜ฆ SSR?! then use the platform! <๐™จ๐™˜๐™ง๐™ž๐™ฅ๐™ฉ ๐™™๐™š๐™›๐™š๐™ง/๐™–๐™จ๐™ฎ๐™ฃ๐™˜/๐™ข๐™ค๐™™๐™ช๐™ก๐™š>

LATE is sometimes preferable depends where/when a component might be used, using <script> for everything can clog the pipes (i don't know what they mean by SSR bundle, don't think that is shipped to the browser?)

We don't scan the source in SSR, merely template it together: we'd need to add another step to detect what custom elements are being used. It ought to improve things, but it's on my "to implement and benchmark later" list: caching and progressive enhancement means I expect it to be very minor.

> need to add another step to detect what custom > elements are being used You already did that step, but execute it on the client Make AI refactor it and you are done in 15 minutes Its like going to Burning Man than having to wait 4 weeks for it to be built then again .. you save maybe 20ms

0 reposts0 likes

I have a vague memory of benchmarking this with a simple regex, and the gains were so minimal it wasn't worth investigating more at that point. You've got me interested again now though! I'll try and find some time this week to try it, and report back.